/*
 * JFileSync
 * Copyright (C) 2002-2005, Jens Heidrich
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301, USA
 */

package jfs.gui;

import java.util.Vector;

import javax.swing.DefaultCellEditor;
import javax.swing.JCheckBox;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.border.EmptyBorder;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableColumnModel;
import javax.swing.table.TableColumn;
import javax.swing.table.TableModel;

import jfs.conf.JFSFilter;
import jfs.conf.JFSText;

/**
 * A table displaying filters (to include/exclude files).
 * 
 * @author Jens Heidrich
 * @version $Id: JFSFilterTable.java,v 1.2 2005/06/27 16:00:05 heidrich Exp $
 */
public class JFSFilterTable extends AbstractTableModel {
	/** The UID. */
	private static final long serialVersionUID = 100L;

	/** The object with information that should be displayed by the table. */
	private final Vector<JFSFilter> filters;

	/** The corresponding JTable. */
	private final JTable table;

	/**
	 * The default constructor.
	 * 
	 * @param filters
	 *            The filters to display.
	 */
	public JFSFilterTable(Vector<JFSFilter> filters) {
		this.filters = filters;

		// Create column model:
		JFSText t = JFSText.getInstance();
		DefaultTableColumnModel cm = new DefaultTableColumnModel();

		JCheckBox cb = new JCheckBox();
		cb.setHorizontalAlignment(JCheckBox.CENTER);

		TableColumn active = new TableColumn(0, 20);
		active.setHeaderValue(t.get("CONFIG_FILTER_ACTIVE"));
		active.setCellEditor(new DefaultCellEditor(cb));
		cm.addColumn(active);

		JTextField editor = new JTextField();
		editor.setBorder(new EmptyBorder(0, 0, 0, 0));

		TableColumn filter = new TableColumn(1, 120);
		filter.setHeaderValue(t.get("CONFIG_FILTER_REGEXP"));
		filter.setCellEditor(new DefaultCellEditor(editor));
		cm.addColumn(filter);

		// Create table:
		table = new JTable(this, cm);
		table.getTableHeader().setReorderingAllowed(false);
	}

	/**
	 * @see TableModel#getRowCount()
	 */
	public final int getRowCount() {
		return filters.size();
	}

	/**
	 * @see TableModel#getColumnCount()
	 */
	public final int getColumnCount() {
		return 2;
	}

	/**
	 * @see TableModel#isCellEditable(int, int)
	 */
	public final boolean isCellEditable(int row, int column) {
		return true;
	}

	/**
	 * @see TableModel#getValueAt(int, int)
	 */
	public final Object getValueAt(int row, int column) {
		switch (column) {
		case 0:
			return filters.get(row).isActive();
		default:
			return filters.get(row).getFilter();
		}
	}

	/**
	 * @see TableModel#getColumnClass(int)
	 */
	public final Class<?> getColumnClass(int column) {
		switch (column) {
		case 0:
			return Boolean.class;
		default:
			return String.class;
		}
	}

	/**
	 * @see TableModel#setValueAt(Object, int, int)
	 */
	public final void setValueAt(Object value, int row, int column) {
		switch (column) {
		case 0:
			filters.get(row).setActive((Boolean) value);
			break;
		default:
			filters.get(row).setFilter((String) value);
			break;
		}
	}

	/**
	 * @return Returns the filters.
	 */
	public final Vector<JFSFilter> getFilters() {
		return filters;
	}

	/**
	 * @return Returns the JTable object.
	 */
	public final JTable getJTable() {
		return table;
	}
}