/*
 * JFileSync
 * Copyright (C) 2002-2005, Jens Heidrich
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301, USA
 */

package jfs.shell;

import jfs.conf.JFSLog;
import jfs.sync.JFSFile;
import jfs.sync.JFSFileVisitor;

/**
 * Visits the directory structure of an JFSFile hierarchie and print the
 * hierarchie to standard out.
 * 
 * @author Jens Heidrich
 * @version $Id: JFSFilePrint.java,v 1.2 2005/06/27 16:00:06 heidrich Exp $
 */
public class JFSFilePrint implements JFSFileVisitor {

	/** The indent string. */
	String indent = "";

	/**
	 * Performed if you enter a JFSFile object that represents a directory.
	 * 
	 * @param dir
	 *            The directory to be entered.
	 */
	public void enterDirectory(JFSFile dir) {
		JFSLog.getOut().getStream().println(indent + "[" + dir.getName() + "]");
		indent += "  ";
	}

	/**
	 * Performed if you leave a JFSFile object that represents a directory.
	 * 
	 * @param dir
	 *            The directory to be left.
	 */
	public void leaveDirectory(JFSFile dir) {
		indent = indent.substring(2);
	}

	/**
	 * Performed if you visit a JFSFile object that represents a file (not a
	 * directory).
	 * 
	 * @param file
	 *            The file to be visited.
	 */
	public void visitFile(JFSFile file) {
		JFSLog.getOut().getStream().println(indent + file.getName());
	}
}