/*
 * JFileSync
 * Copyright (C) 2002-2005, Jens Heidrich
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA, 02110-1301, USA
 */

package jfs.shell;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintStream;

import jfs.conf.JFSLog;
import jfs.conf.JFSText;
import jfs.conf.JFSSyncMode.SyncAction;
import jfs.sync.JFSElement;
import jfs.sync.JFSQuestion;
import jfs.sync.JFSQuestionOracle;
import jfs.sync.JFSQuestion.QuestionAnswer;

/**
 * A JFS questions oracle which asks the user on the command line to determine
 * an action for a JFS element.
 * 
 * @author Jens Heidrich
 * @version $Id: JFSQuestionPrint.java,v 1.2 2005/06/27 16:00:06 heidrich Exp $
 */
public class JFSQuestionPrint implements JFSQuestionOracle {

	/**
	 * @see JFSQuestionOracle#ask(JFSQuestion)
	 */
	public final QuestionAnswer ask(JFSQuestion question) {
		PrintStream p = JFSLog.getOut().getStream();
		JFSText t = JFSText.getInstance();
		JFSElement e = question.getElement();

		p.println();
		p.println(question.getQuestionText());
		p.println("  " + t.get("QUESTION_PRINT_SRC_FILE") + " "
				+ JFSPrint.adapt(e.getSrcFile().getPath(), 40) + " ("
				+ e.getSrcFile().getLastModifiedDate() + ")");
		p.println("  " + t.get("QUESTION_PRINT_TGT_FILE") + " "
				+ JFSPrint.adapt(e.getTgtFile().getPath(), 40) + " ("
				+ e.getTgtFile().getLastModifiedDate() + ")");
		p.println();
		p.println(t.get("QUESTION_PRINT_ACTIONS_HELP"));
		p.println("  " + t.get("QUESTION_PRINT_ACTIONS"));

		BufferedReader din = new BufferedReader(
				new InputStreamReader(System.in));
		try {
			String input = din.readLine().toLowerCase();
			if (input.equals("1")) {
				p.println("  " + t.get("QUESTION_PRINT_ACTION_COPY_SRC"));
				p.println();
				question.setAction(SyncAction.COPY_SRC);
				return QuestionAnswer.DO;
			} else if (input.equals("2")) {
				p.println("  " + t.get("QUESTION_PRINT_ACTION_COPY_TGT"));
				p.println();
				question.setAction(SyncAction.COPY_TGT);
				return QuestionAnswer.DO;
			} else if (input.equals("4")) {
				p.println("  " + t.get("QUESTION_PRINT_ACTION_SKIP_ALL"));
				p.println();
				return QuestionAnswer.SKIP_ALL;
			}
		} catch (IOException exeption) {
			JFSLog.getErr().getStream().println(t.get("ERROR_INPUT_READ"));
		}

		// Skip question by default:
		p.println("  " + t.get("QUESTION_PRINT_ACTION_SKIP"));
		p.println();
		return QuestionAnswer.SKIP;
	}
}